@@ -29,7 +29,7 @@ while ( <DATA> )
     $total++;
     my $error = $address->parse($address_in);
 
-    my %comps = $address->case_components;
+    my %comps = $address->components;
     my %props = $address->properties;
 
     if ( $error and $props{type} eq 'unknown' )
